pub struct ConcurrentBloom<T> { /* private fields */ }This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Bloom filter that can be used concurrently. Concurrent reads/writes are safe, but are not atomic at the struct level, this means that reads may see partial writes.
Implementations
Sourceimpl<T: BloomHashIndex> ConcurrentBloom<T>
impl<T: BloomHashIndex> ConcurrentBloom<T>
Sourcepub fn add(&self, key: &T) -> bool
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn add(&self, key: &T) -> bool
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Adds an item to the bloom filter and returns true if the item was not in the filter before.
pub fn contains(&self, key: &T) -> bool
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn clear(&self)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.